==> igniteui-react-charts-16.4.1.tgz: package/ES5/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-react-core/ES5/Brush";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, runOn, markType, fromEnum } from "igniteui-react-core/ES5/type";
import { Rect } from "igniteui-react-core/ES5/Rect";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
import { ArrayExtension } from "igniteui-react-core/ES5/ArrayExtension";
import { Rectangle } from "igniteui-react-core/ES5/Rectangle";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_ } from "igniteui-react-core/ES5/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
var WaterfallSeries = /** @class */ (function (_super) {
    tslib_1.__extends(WaterfallSeries, _super);
    function WaterfallSeries() {
        var _this = _super.call(this) || this;
        _this.ab = WaterfallSeries.$;
        return _this;
    }
    WaterfallSeries.prototype.bf = function () {
        return new WaterfallSeriesView(this);
    };
    WaterfallSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.p7 = a;
    };
    WaterfallSeries.prototype.preferredCategoryMode = function (a) {
        return 2;
    };
    WaterfallSeries.prototype.get_cz = function () {
        return true;
    };
    Object.defineProperty(WaterfallSeries.prototype, "cz", {
        get: function () {
            return this.get_cz();
        },
        enumerable: true,
        configurable: true
    });
    WaterfallSeries.prototype.i9 = function (a, b) {
        _super.prototype.i9.call(this, a, b);
        this.qi = a;
        this.qj = b;
    };
    WaterfallSeries.prototype.k0 = function () {
        return this.qi;
    };
    WaterfallSeries.prototype.get_nm = function () {
        return true;
    };
    Object.defineProperty(WaterfallSeries.prototype, "nm", {
        get: function () {
            return this.get_nm();
        },
        enumerable: true,
        configurable: true
    });
    WaterfallSeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case WaterfallSeries.$$p[3]:
            case WaterfallSeries.$$p[2]:
            case WaterfallSeries.$$p[0]:
            case WaterfallSeries.$$p[1]:
                this.i4(false);
                break;
        }
    };
    WaterfallSeries.prototype.df = function (a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    };
    WaterfallSeries.prototype.ll = function (a) {
        var _this = this;
        if (this.p7 == null || this.p7.c5 == null || this.p7.c5.count == 0 || this.xAxis == null) {
            return Rect.empty;
        }
        var b = this.p7.c5;
        var c = this.k7(a);
        var d = -1;
        var e = this.xAxis.b8;
        var f = this.lp.right * 2;
        if (e) {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.p7.dc(g);
                return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
            });
        }
        else {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.p7.dc(g);
                return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
            });
        }
        if (d < 0) {
            d = ~d;
            d--;
        }
        if (d < 0) {
            d = 0;
        }
        if (d > b.count - 1) {
            d = b.count - 1;
        }
        var g = d;
        var h = d;
        if (g < 0) {
            g--;
        }
        if (h < b.count - 1) {
            h++;
        }
        var i = this.qk(g);
        var j = this.qk(d);
        var k = this.qk(h);
        var l = i.left + i.width / 2;
        var m = j.left + j.width / 2;
        var n = k.left + k.width / 2;
        var o = Math.abs(l - c.x);
        var p = Math.abs(m - c.x);
        var q = Math.abs(n - c.x);
        var r = i.containsPoint(c);
        var s = j.containsPoint(c);
        var t = k.containsPoint(c);
        if (p <= o && p <= q) {
            if (!e && t) {
                return k;
            }
            if (e && r) {
                return i;
            }
            return j;
        }
        if (o <= p && o <= q) {
            if (!e && s) {
                return j;
            }
            return i;
        }
        if (q <= p && q <= o) {
            if (e && s) {
                return j;
            }
            return k;
        }
        return Rect.empty;
    };
    WaterfallSeries.prototype.qk = function (a) {
        return this.p7.db(a);
    };
    WaterfallSeries.prototype.m7 = function () {
        return 1;
    };
    WaterfallSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        this.p7.c5.count = 0;
    };
    WaterfallSeries.prototype.ec = function () {
        return this.po.jk(this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi));
    };
    WaterfallSeries.prototype.oe = function (a, b) {
        var c = b;
        _super.prototype.oe.call(this, a, b);
        var d = b.bq;
        var e = b.bp;
        var f = this.getEffectiveViewport1(b);
        var g = this.po.jk(d, e, f);
        var h = this.p8;
        var i = this.p9;
        var j;
        var k = this.ox(b);
        var l = NaN;
        var m = c.c5;
        var n;
        var o = 0;
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.p8;
        this.m5.q = this.p9;
        this.m5.j = this.p8;
        this.m5.k = this.p9;
        var p = false;
        var q = this.m5.c;
        if (q != null) {
            p = true;
        }
        var r = this.po.cc;
        var s = this.valueColumn.count;
        var t = a.f;
        var u = this.po;
        var v = new ScalerParams(0, d, e, this.po.b8, f);
        var w = this.ku;
        var x = this.qi;
        var y = this.kv;
        var z = this.qj || y;
        if (a.f.count > 0) {
            j = a.f._inner[0][0] - 0.5 * g;
            var aa = a.f._inner[0][1];
            if (!isNaN_(aa)) {
                if (aa > k) {
                    n = m.item(o);
                    o++;
                    c.da(n, j, k);
                    n.width = g;
                    n.height = Math.abs(k - aa);
                    this.m5.al = x;
                    this.m5.ah = x;
                    this.m5.am = z;
                    this.m5.ai = z;
                    this.m5.f = true;
                    if (p) {
                        this.oa(t, 0, s, u, v, b.n);
                    }
                    this.m5.ae(n, false, false, false, false);
                    n.al = this.m5.j;
                    n.am = this.m5.k;
                }
                else {
                    n = m.item(o);
                    o++;
                    c.da(n, j, aa);
                    n.width = g;
                    n.height = Math.abs(aa - k);
                    this.m5.al = w;
                    this.m5.ah = w;
                    this.m5.am = y;
                    this.m5.ai = y;
                    this.m5.f = false;
                    if (p) {
                        this.oa(t, 0, s, u, v, b.n);
                    }
                    this.m5.ae(n, false, false, false, false);
                    n.al = this.m5.j;
                    n.am = this.m5.k;
                }
                l = aa;
            }
            else {
                l = k;
            }
        }
        for (var ab = 1; ab < a.f.count; ++ab) {
            var ac = a.f._inner[ab];
            j = a.f._inner[ab][0] - 0.5 * g;
            var ad = ac[1];
            if (!isNaN_(ad)) {
                n = m.item(o);
                o++;
                c.da(n, j, Math.min(l, ad));
                n.width = g;
                n.height = Math.abs(l - ad);
                this.m5.al = w;
                this.m5.ah = w;
                this.m5.am = y;
                this.m5.ai = y;
                this.m5.f = false;
                if (l > ad) {
                    if (p) {
                        this.oa(t, ab, s, u, v, b.n);
                    }
                }
                else {
                    this.m5.al = x;
                    this.m5.ah = x;
                    this.m5.am = z;
                    this.m5.ai = z;
                    this.m5.f = true;
                    if (p) {
                        this.oa(t, ab, s, u, v, b.n);
                    }
                }
                this.m5.ae(n, false, false, false, false);
                n.al = this.m5.j;
                n.am = this.m5.k;
                l = ad;
            }
        }
        m.count = o;
        b.cs(a);
    };
    Object.defineProperty(WaterfallSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
    return WaterfallSeries;
}(HorizontalAnchoredCategorySeries));
export { WaterfallSeries };
Type.dep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:qi:qe', [Brush.$, null], 'NegativeOutline:qj:qf', [Brush.$, null], 'RadiusX:p8:qg', [1, 2], 'RadiusY:p9:qh', [1, 2]]);
var WaterfallSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(WaterfallSeriesView, _super);
    function WaterfallSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c4 = null;
        _this.c6 = null;
        _this.dd = new Rectangle();
        _this.c5 = null;
        _this.c4 = a;
        _this.c5 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.de);
            $ret.activate = runOn(_this, _this.c7);
            $ret.disactivate = runOn(_this, _this.c9);
            $ret.destroy = runOn(_this, _this.c8);
            return $ret;
        })());
        return _this;
    }
    WaterfallSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        this.c6 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.c4.qi = ((function () {
                var $ret = new Brush();
                $ret.fill = "#C62828";
                return $ret;
            })());
            this.c4.qj = ((function () {
                var $ret = new Brush();
                $ret.fill = "#C62828";
                return $ret;
            })());
            this.e.bj = 5;
        }
    };
    WaterfallSeriesView.prototype.de = function () {
        var a = new Rectangle();
        this.c6.add(a);
        a._visibility = 1;
        return a;
    };
    WaterfallSeriesView.prototype.c7 = function (a) {
        a._visibility = 0;
    };
    WaterfallSeriesView.prototype.c9 = function (a) {
        a._visibility = 1;
    };
    WaterfallSeriesView.prototype.c8 = function (a) {
        this.c6.remove(a);
    };
    WaterfallSeriesView.prototype.da = function (a, b, c) {
        var d = false;
        if (a.o != c) {
            d = true;
            a.o = c;
        }
        if (a.n != b) {
            d = true;
            a.n = b;
        }
        if (d) {
            this.an();
        }
    };
    WaterfallSeriesView.prototype.z = function (a) {
        return this.c6._inner[a];
    };
    WaterfallSeriesView.prototype.y = function (a) {
        var b = this.c6._inner[a];
        this.dd._visibility = b._visibility;
        this.dd.n = b.n;
        this.dd.o = b.o;
        this.dd.width = b.width;
        this.dd.height = b.height;
        var c = this.bl(a);
        this.dd._fill = c;
        this.dd._stroke = c;
        this.dd.ac = this.e.eu + 3;
        return this.dd;
    };
    WaterfallSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.c6.count; c++) {
                var d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    };
    WaterfallSeriesView.prototype.ai = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.ai.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = tslib_1.__values(fromEnum(this.c5.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
            }
            finally { if (e_1) throw e_1.error; }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = tslib_1.__values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                var f = "Negative";
                if (e._fill == this.e.ku) {
                    f = "Positive";
                }
                this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", f]);
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
            }
            finally { if (e_2) throw e_2.error; }
        }
        b++;
    };
    WaterfallSeriesView.prototype.db = function (a) {
        var b = this.c5.item(a);
        return new Rect(0, b.n, b.o, b.width, b.height);
    };
    WaterfallSeriesView.prototype.dc = function (a) {
        return new Rect(0, a.n, a.o, a.width, a.height);
    };
    WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
    return WaterfallSeriesView;
}(AnchoredCategorySeriesView));
export { WaterfallSeriesView };
/*<BeginStatics Name="Infragistics.Controls.Charts.WaterfallSeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.WaterfallSeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES5/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-react-core/ES5/Brush";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, runOn, markType, fromEnum } from "igniteui-react-core/ES5/type";
import { Rect } from "igniteui-react-core/ES5/Rect";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
import { Rectangle } from "igniteui-react-core/ES5/Rectangle";
import { ArrayExtension } from "igniteui-react-core/ES5/ArrayExtension";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_ } from "igniteui-react-core/ES5/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
var WaterfallSeries = /** @class */ (function (_super) {
    tslib_1.__extends(WaterfallSeries, _super);
    function WaterfallSeries() {
        var _this = _super.call(this) || this;
        _this.ab = WaterfallSeries.$;
        return _this;
    }
    WaterfallSeries.prototype.bf = function () {
        return new WaterfallSeriesView(this);
    };
    WaterfallSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.p8 = a;
    };
    WaterfallSeries.prototype.preferredCategoryMode = function (a) {
        return 2;
    };
    WaterfallSeries.prototype.get_cz = function () {
        return true;
    };
    WaterfallSeries.prototype.i9 = function (a, b) {
        _super.prototype.i9.call(this, a, b);
        this.qj = a;
        this.qk = b;
    };
    WaterfallSeries.prototype.k0 = function () {
        return this.qj;
    };
    WaterfallSeries.prototype.get_nm = function () {
        return true;
    };
    WaterfallSeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case WaterfallSeries.$$p[3]:
            case WaterfallSeries.$$p[2]:
            case WaterfallSeries.$$p[0]:
            case WaterfallSeries.$$p[1]:
                this.i4(false);
                break;
        }
    };
    WaterfallSeries.prototype.df = function (a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    };
    WaterfallSeries.prototype.ll = function (a) {
        var _this = this;
        if (this.p8 == null || this.p8.c7 == null || this.p8.c7.count == 0 || this.xAxis == null) {
            return Rect.empty;
        }
        var b = this.p8.c7;
        var c = this.k7(a);
        var d = -1;
        var e = this.xAxis.b8;
        var f = this.lp.right * 2;
        if (e) {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.p8.de(g);
                return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
            });
        }
        else {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.p8.de(g);
                return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
            });
        }
        if (d < 0) {
            d = ~d;
            d--;
        }
        if (d < 0) {
            d = 0;
        }
        if (d > b.count - 1) {
            d = b.count - 1;
        }
        var g = d;
        var h = d;
        if (g < 0) {
            g--;
        }
        if (h < b.count - 1) {
            h++;
        }
        var i = this.ql(g);
        var j = this.ql(d);
        var k = this.ql(h);
        var l = i.left + i.width / 2;
        var m = j.left + j.width / 2;
        var n = k.left + k.width / 2;
        var o = Math.abs(l - c.x);
        var p = Math.abs(m - c.x);
        var q = Math.abs(n - c.x);
        var r = i.containsPoint(c);
        var s = j.containsPoint(c);
        var t = k.containsPoint(c);
        if (p <= o && p <= q) {
            if (!e && t) {
                return k;
            }
            if (e && r) {
                return i;
            }
            return j;
        }
        if (o <= p && o <= q) {
            if (!e && s) {
                return j;
            }
            return i;
        }
        if (q <= p && q <= o) {
            if (e && s) {
                return j;
            }
            return k;
        }
        return Rect.empty;
    };
    WaterfallSeries.prototype.ql = function (a) {
        return this.p8.dd(a);
    };
    WaterfallSeries.prototype.m7 = function () {
        return 1;
    };
    WaterfallSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        this.p8.c7.count = 0;
    };
    WaterfallSeries.prototype.ec = function () {
        return this.pp.jk(this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    };
    WaterfallSeries.prototype.of = function (a, b) {
        var c = b;
        _super.prototype.of.call(this, a, b);
        var d = b.bs;
        var e = b.br;
        var f = this.getEffectiveViewport1(b);
        var g = this.pp.jk(d, e, f);
        var h = this.p9;
        var i = this.qa;
        var j;
        var k = this.oy(b);
        var l = NaN;
        var m = c.c7;
        var n;
        var o = 0;
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.p9;
        this.m5.q = this.qa;
        this.m5.j = this.p9;
        this.m5.k = this.qa;
        var p = false;
        var q = this.m5.c;
        if (q != null) {
            p = true;
        }
        var r = this.pp.cc;
        var s = this.valueColumn.count;
        var t = a.f;
        var u = this.pp;
        var v = new ScalerParams(0, d, e, this.pp.b8, f);
        var w = this.ku;
        var x = this.qj;
        var y = this.kv;
        var z = this.qk || y;
        if (a.f.count > 0) {
            j = a.f._inner[0][0] - 0.5 * g;
            var aa = a.f._inner[0][1];
            if (!isNaN_(aa)) {
                if (aa > k) {
                    n = m.item(o);
                    o++;
                    c.dc(n, j, k);
                    n.width = g;
                    n.height = Math.abs(k - aa);
                    this.m5.al = x;
                    this.m5.ah = x;
                    this.m5.am = z;
                    this.m5.ai = z;
                    this.m5.f = true;
                    if (p) {
                        this.ob(t, 0, s, u, v, b.n);
                    }
                    this.m5.ae(n, false, false, false, false);
                    n.al = this.m5.j;
                    n.am = this.m5.k;
                }
                else {
                    n = m.item(o);
                    o++;
                    c.dc(n, j, aa);
                    n.width = g;
                    n.height = Math.abs(aa - k);
                    this.m5.al = w;
                    this.m5.ah = w;
                    this.m5.am = y;
                    this.m5.ai = y;
                    this.m5.f = false;
                    if (p) {
                        this.ob(t, 0, s, u, v, b.n);
                    }
                    this.m5.ae(n, false, false, false, false);
                    n.al = this.m5.j;
                    n.am = this.m5.k;
                }
                l = aa;
            }
            else {
                l = k;
            }
        }
        for (var ab = 1; ab < a.f.count; ++ab) {
            var ac = a.f._inner[ab];
            j = a.f._inner[ab][0] - 0.5 * g;
            var ad = ac[1];
            if (!isNaN_(ad)) {
                n = m.item(o);
                o++;
                c.dc(n, j, Math.min(l, ad));
                n.width = g;
                n.height = Math.abs(l - ad);
                this.m5.al = w;
                this.m5.ah = w;
                this.m5.am = y;
                this.m5.ai = y;
                this.m5.f = false;
                if (l > ad) {
                    if (p) {
                        this.ob(t, ab, s, u, v, b.n);
                    }
                }
                else {
                    this.m5.al = x;
                    this.m5.ah = x;
                    this.m5.am = z;
                    this.m5.ai = z;
                    this.m5.f = true;
                    if (p) {
                        this.ob(t, ab, s, u, v, b.n);
                    }
                }
                this.m5.ae(n, false, false, false, false);
                n.al = this.m5.j;
                n.am = this.m5.k;
                l = ad;
            }
        }
        m.count = o;
        b.cu(a);
    };
    Object.defineProperty(WaterfallSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
    return WaterfallSeries;
}(HorizontalAnchoredCategorySeries));
export { WaterfallSeries };
Type.dep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:qj:qf', [Brush.$, null], 'NegativeOutline:qk:qg', [Brush.$, null], 'RadiusX:p9:qh', [1, 2], 'RadiusY:qa:qi', [1, 2]]);
var WaterfallSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(WaterfallSeriesView, _super);
    function WaterfallSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c6 = null;
        _this.c8 = null;
        _this.df = new Rectangle();
        _this.c7 = null;
        _this.c6 = a;
        _this.c7 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.dg);
            $ret.activate = runOn(_this, _this.c9);
            $ret.disactivate = runOn(_this, _this.db);
            $ret.destroy = runOn(_this, _this.da);
            return $ret;
        })());
        return _this;
    }
    WaterfallSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        this.c8 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.c6.qj = ((function () {
                var $ret = new Brush();
                $ret.fill = "#C62828";
                return $ret;
            })());
            this.c6.qk = ((function () {
                var $ret = new Brush();
                $ret.fill = "#C62828";
                return $ret;
            })());
            this.e.bj = 5;
        }
    };
    WaterfallSeriesView.prototype.dg = function () {
        var a = new Rectangle();
        this.c8.add(a);
        a._visibility = 1;
        return a;
    };
    WaterfallSeriesView.prototype.c9 = function (a) {
        a._visibility = 0;
    };
    WaterfallSeriesView.prototype.db = function (a) {
        a._visibility = 1;
    };
    WaterfallSeriesView.prototype.da = function (a) {
        this.c8.remove(a);
    };
    WaterfallSeriesView.prototype.dc = function (a, b, c) {
        var d = false;
        if (a.o != c) {
            d = true;
            a.o = c;
        }
        if (a.n != b) {
            d = true;
            a.n = b;
        }
        if (d) {
            this.an();
        }
    };
    WaterfallSeriesView.prototype.z = function (a) {
        return this.c8._inner[a];
    };
    WaterfallSeriesView.prototype.y = function (a) {
        var b = this.c8._inner[a];
        this.df._visibility = b._visibility;
        this.df.n = b.n;
        this.df.o = b.o;
        this.df.width = b.width;
        this.df.height = b.height;
        var c = this.bm(a);
        this.df._fill = c;
        this.df._stroke = c;
        this.df.ac = this.e.eu + 3;
        return this.df;
    };
    WaterfallSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.c8.count; c++) {
                var d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    };
    WaterfallSeriesView.prototype.ai = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.ai.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = tslib_1.__values(fromEnum(this.c7.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
            }
            finally { if (e_1) throw e_1.error; }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = tslib_1.__values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                var f = "Negative";
                if (e._fill == this.e.ku) {
                    f = "Positive";
                }
                this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", f]);
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
            }
            finally { if (e_2) throw e_2.error; }
        }
        b++;
    };
    WaterfallSeriesView.prototype.dd = function (a) {
        var b = this.c7.item(a);
        return new Rect(0, b.n, b.o, b.width, b.height);
    };
    WaterfallSeriesView.prototype.de = function (a) {
        return new Rect(0, a.n, a.o, a.width, a.height);
    };
    WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
    return WaterfallSeriesView;
}(AnchoredCategorySeriesView));
export { WaterfallSeriesView };
